redvox.api1000.errors API documentation
Description: This module provides custom exception types for API 1000 related errors.

# Module `redvox.api1000.errors`

This module provides custom exception types for API 1000 related errors.

Expand source code

    """
    This module provides custom exception types for API 1000 related errors.
    """

    class ApiMError(Exception):
        """
        Base API Error class. All other error classes should be subclasses of this one.
        """

        def __init__(self, message: str):
            super().__init__(f"ApiMError: {message}")

    class SummaryStatisticsError(ApiMError):
        """
        An error with summary statistics.
        """

        def __init__(self, message: str):
            super().__init__(f"SummaryStatisticsError: {message}")

    class AudioChannelError(ApiMError):
        """
        An audio channel error.
        """

        def __init__(self, message: str):
            super().__init__(f"AudioChannelError: {message}")

    class SingleChannelError(ApiMError):
        """
        A single channel error.
        """

        def __init__(self, message: str):
            super().__init__(f"SingleChannelError: {message}")

    class XyzChannelError(ApiMError):
        """
        An xyz channel error.
        """

        def __init__(self, message: str):
            super().__init__(f"XyzChannelError: {message}")

    class LocationChannelError(ApiMError):
        """
        A location channel error
        """

        def __init__(self, message: str):
            super().__init__(f"LocationChannelError: {message}")

    class ApiMTypeError(ApiMError):
        """
        A type error.
        """

        def __init__(self, message: str):
            super().__init__(f"ApiMTypeError: {message}")

    class WrappedRedvoxPacketMError(ApiMError):
        """
        A wrapped packet error.
        """

        def __init__(self, message: str):
            super().__init__(f"WrappedRedvoxPacketMError: {message}")

    class ApiMConcatenationError(ApiMError):
        """
        A concatenation error.
        """

        def __init__(self, message: str):
            super().__init__(f"ApiMConcatenationError: {message}")

    class ApiMImageChannelError(ApiMError):
        """
        An image sensor error.
        """

        def __init__(self, message: str):
            super().__init__(f"ApiMImageChannelError: {message}")

    class ApiMOtherError(ApiMError):
        """
        A generic error.
        """

        def __init__(self, message: str):
            super().__init__(f"ApiMOtherError: {message}")

## Classes

`class ApiMConcatenationError (message: str)`

  A concatenation error.

  Expand source code

      class ApiMConcatenationError(ApiMError):
          """
          A concatenation error.
          """

          def __init__(self, message: str):
              super().__init__(f"ApiMConcatenationError: {message}")

  ### Ancestors

  - ApiMError
  - builtins.Exception
  - builtins.BaseException
`class ApiMError (message: str)`

  Base API Error class. All other error classes should be subclasses of this one.

  Expand source code

      class ApiMError(Exception):
          """
          Base API Error class. All other error classes should be subclasses of this one.
          """

          def __init__(self, message: str):
              super().__init__(f"ApiMError: {message}")

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException

  ### Subclasses

  - ApiMConcatenationError
  - ApiMImageChannelError
  - ApiMOtherError
  - ApiMTypeError
  - AudioChannelError
  - LocationChannelError
  - SingleChannelError
  - SummaryStatisticsError
  - WrappedRedvoxPacketMError
  - XyzChannelError
`class ApiMImageChannelError (message: str)`

  An image sensor error.

  Expand source code

      class ApiMImageChannelError(ApiMError):
          """
          An image sensor error.
          """

          def __init__(self, message: str):
              super().__init__(f"ApiMImageChannelError: {message}")

  ### Ancestors

  - ApiMError
  - builtins.Exception
  - builtins.BaseException
`class ApiMOtherError (message: str)`

  A generic error.

  Expand source code

      class ApiMOtherError(ApiMError):
          """
          A generic error.
          """

          def __init__(self, message: str):
              super().__init__(f"ApiMOtherError: {message}")

  ### Ancestors

  - ApiMError
  - builtins.Exception
  - builtins.BaseException
`class ApiMTypeError (message: str)`

  A type error.

  Expand source code

      class ApiMTypeError(ApiMError):
          """
          A type error.
          """

          def __init__(self, message: str):
              super().__init__(f"ApiMTypeError: {message}")

  ### Ancestors

  - ApiMError
  - builtins.Exception
  - builtins.BaseException
`class AudioChannelError (message: str)`

  An audio channel error.

  Expand source code

      class AudioChannelError(ApiMError):
          """
          An audio channel error.
          """

          def __init__(self, message: str):
              super().__init__(f"AudioChannelError: {message}")

  ### Ancestors

  - ApiMError
  - builtins.Exception
  - builtins.BaseException
`class LocationChannelError (message: str)`

  A location channel error

  Expand source code

      class LocationChannelError(ApiMError):
          """
          A location channel error
          """

          def __init__(self, message: str):
              super().__init__(f"LocationChannelError: {message}")

  ### Ancestors

  - ApiMError
  - builtins.Exception
  - builtins.BaseException
`class SingleChannelError (message: str)`

  A single channel error.

  Expand source code

      class SingleChannelError(ApiMError):
          """
          A single channel error.
          """

          def __init__(self, message: str):
              super().__init__(f"SingleChannelError: {message}")

  ### Ancestors

  - ApiMError
  - builtins.Exception
  - builtins.BaseException
`class SummaryStatisticsError (message: str)`

  An error with summary statistics.

  Expand source code

      class SummaryStatisticsError(ApiMError):
          """
          An error with summary statistics.
          """

          def __init__(self, message: str):
              super().__init__(f"SummaryStatisticsError: {message}")

  ### Ancestors

  - ApiMError
  - builtins.Exception
  - builtins.BaseException
`class WrappedRedvoxPacketMError (message: str)`

  A wrapped packet error.

  Expand source code

      class WrappedRedvoxPacketMError(ApiMError):
          """
          A wrapped packet error.
          """

          def __init__(self, message: str):
              super().__init__(f"WrappedRedvoxPacketMError: {message}")

  ### Ancestors

  - ApiMError
  - builtins.Exception
  - builtins.BaseException
`class XyzChannelError (message: str)`

  An xyz channel error.

  Expand source code

      class XyzChannelError(ApiMError):
          """
          An xyz channel error.
          """

          def __init__(self, message: str):
              super().__init__(f"XyzChannelError: {message}")

  ### Ancestors

  - ApiMError
  - builtins.Exception
  - builtins.BaseException